<?php

class S3UploadCredentials
{
    public static $accessKey;
    public static $secretKey;
    public static $bucket;
    public static $file;
    public static $contentType;
    public static $redirectUrl;
    public static $endpoint = 's3.amazonaws.com';
    public static $acl = 'public-read';

    function __construct($accessKey = null, $secretKey = null, $bucket = null, $acl = null)
    {
        if ($accessKey !== null && $secretKey !== null)
           self::setAuth($accessKey, $secretKey);

        if ($bucket !== null)
           self::setBucket($bucket);

        if ($acl !== null)
           self::setACL($acl);
    }

	public static function setAuth($accessKey, $secretKey)
	{
		self::$accessKey = $accessKey;
		self::$secretKey = $secretKey;
	}


    public static function hasAuth()
    {
        return (self::$accessKey !== null && self::$secretKey !== null);
    }


	public static function setACL($acl)
	{
		self::$acl = $acl;
	}


	public static function setEndpoint($endpoint)
	{
		self::$endpoint = $endpoint;
	}


	public static function setBucket($bucket)
	{
		self::$bucket = $bucket;
	}


	public static function setFilename($file)
	{
		self::$file = $file;
	}


	public static function setRedirectUrl($url)
	{
		self::$redirectUrl = $url;
	}    
    
    
    public static function setContentType($type)     
    {
        self::$contentType = strpos($type, '/') !== false ? $type : null;
    }


    public static function getContentType($file = null)
    {            
        if (self::$contentType !== null)
            return self::$contentType;
            
        self::$contentType = FileExtensionMime::get($file);
        return self::$contentType;
    }


    private static function getExpiration()
    {
        return date('Y-m-d\TG:i:s\Z', strtotime('+6 hours'));
    }


    public static function getPolicy($bucket, $acl, $file, $ctype)
    {
        $policy = array(
            'expiration' => self::getExpiration(),
            'conditions' => array(
                array(
                    'bucket' => $bucket
                ),
                array(
                    'acl' => $acl
                ),
                array(
                    'starts-with',
                    '$key',
                    $file,                    
                ),
                array(
                    'starts-with',
                    '$Content-Type',
                    $ctype,                    
                )                
            )
        );
        
        if (!empty(self::$redirectUrl)) {
            $policy['conditions'][] = array(
                'success_action_redirect' => self::$redirectUrl
            );
        }

        return base64_encode(json_encode($policy));
    }


    public static function getSignature($policy)
    {
        return base64_encode(hash_hmac('sha1', $policy, self::$secretKey, true));
    }


    public static function getResponse()
    {
        $ctype = self::getContentType(self::$file);
        $policy = self::getPolicy(self::$bucket, self::$acl, self::$file, $ctype);                

        return json_encode(array(
            'success' => self::hasAuth() && !empty(self::$bucket) ? true : false,
            'contentType' => $ctype,
            'AWSAccessKeyId' => self::$accessKey,
            'acl' => self::$acl,
            'policy' => $policy,
            'signature' => self::getSignature($policy),
            'success_action_redirect' => self::$redirectUrl
        ));
    }

}
