<?php

class ViewSettings
{

    private static $phpVersion;
    private static $maxSize = 0;
    private static $uploadDir;
    
    public static function setMaxSize($size) {
        self::$maxSize = $size;
    }
    
    public static function setUploadDir($dir) {
        self::$uploadDir = $dir;
    }    
    
    public static function getUploadDir() {
        $dir = self::$uploadDir;
        
        if (empty($dir))
            return $dir;

        $slash = DIRECTORY_SEPARATOR;            
        $dir = str_replace('/', $slash, $dir);
        $dir = str_replace('\\', $slash, $dir);
        return substr($dir, -1) == $slash ? $dir : $dir . $slash;
    }
    
private static function toBytes($size) {
    if (substr($size, -1) == 'M') {
        $size = substr($size, 0, -1);
        return (int)$size * 1024;
    }
    else if (substr($size, -1) == 'G') {
        $size = substr($size, 0, -1);
        return (int)$size * 1024 * 1024;        
    }
    else {
        return $size;
    }
}    

private static function toMegaBytes($size) {
    $mb = round($size / 1024);
    return $mb . 'M';
}    

private static function getCSS() {
    return <<<EOB
    <style type="text/css">
    body {
        font-family:Helvetica, Arial, sans-serif;
        font-size: 15px;
        line-height: 20px;
        color: #444;
       background-color: #fafafa; 
    }
    table {
        background-color: transparent;
      border-spacing: 0;
      border-collapse: collapse;
      width: 100%;
      max-width: 100%;
      margin-bottom: 20px;
      border: 1px solid #ddd;
    }
    td,th {
        padding: 8px;
      background-color: #fff;
      border: 1px solid #ddd;
      text-align: center;
    }
    .container {
      padding-right: 15px;
      padding-left: 15px;
      margin-right: auto;
      margin-left: auto;
    }
    @media (min-width: 768px) {
      .container {
        width: 750px;
      }
    }
    @media (min-width: 992px) {
      .container {
        width: 970px;
      }
    }
    @media (min-width: 1200px) {
      .container {
        width: 1170px;
      }
    }    
    .row {
      margin-right: -15px;
      margin-left: -15px;
    }
    .container:before,
    .container:after,
    .row:before,
    .row:after {
      display: table;
      content: " ";
    }    
    .container:after,
    .row:after {
        clear:both;
    }
    h3 {
        font-size: 22px;
        margin: 10px 0;
    }
    .error td {
        background-color: #F77777;
        font-weight: bold;
    }
    </style>
EOB;
}

private static function getIniValue($ini) {
    $value = ini_get($ini);
    if ($value === '1' || $value === '0') {
        $value = ($value) ? 'true' : 'false';
    }
    return $value;
}

public static function getHTML() {
    $css = self::getCSS();
    self::$phpVersion = phpversion();
    $version = self::$phpVersion;
    $major = substr($version, 0, 3);
    
    $server = $_SERVER["SERVER_SOFTWARE"];
    
    $uploads = self::getIniValue('file_uploads');
    $maxfile = self::getIniValue('upload_max_filesize');
    $postmax = self::getIniValue('post_max_size');

    $maxfile_tr = '';
    $maxfile_msg = '';    
    
    if (self::toBytes($maxfile) < self::$maxSize) {
        $maxfile_tr = 'error';
        $maxfile_msg = '$sizeLimit setting exceeds PHP ini setting for upload_max_filesize';
    }
    
    $postmax_tr = '';
    $postmax_msg = '';    
    
    if (self::toBytes($postmax) < self::$maxSize) {
        $postmax_tr = 'error';
        $postmax_msg = '$sizeLimit setting exceeds PHP ini setting for post_max_size';
    }
    
    $inifile = php_ini_loaded_file();
    
    $maxsize = self::$maxSize;
    $maxsize_mb = self::toMegaBytes($maxsize);
    $uploaddir = self::getUploadDir();
    
    $writable_tr = '';
    $writable_msg = '';
    
    if (!is_writable($uploaddir)) {
        $writable_tr = 'error';
        $writable_msg = 'Directory either does not exist or does is not writable.';    
    }
    
    echo <<<EOB
    <!DOCTYPE html>
    <html lang="en">
        <head>
            <meta http-equiv="Content-type" content="text/html; charset=UTF-8">
            <title>Simple Ajax Uploader</title>
            $css
        </head>
        <body>
            <div class="container">
                <div class="row">
                    <h3>Upload Settings</h3>
                    <table>
                        <tbody>
                            <tr><td>maxSize</td><td>$maxsize bytes ($maxsize_mb)</td><td></td></tr>
                            <tr class="$writable_tr"><td>uploadDir</td><td>$uploaddir</td><td>$writable_msg</td></tr>
                            <tr><td>allowedExtensions</td><td></td><td></td></tr>
                        </tbody>
                    </table>                                        
                </div>            
            
                <div class="row">
                    <h3>System</h3>
                    <table>
                        <tbody>
                            <tr><td>PHP version</td><td>$version</td></tr>
                            <tr><td>Path to loaded php.ini file</td><td>$inifile</td></tr>
                            <tr><td>Server</td><td>$server</td></tr>
                        </tbody>
                    </table>                                        
                </div>
                
                
                <div class="row">
                    <h3>Uploads</h3>
                    <table>
                        <thead>
                            <tr>
                                <th>Setting</th>
                                <th>Value</th>
                                <th>Note</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr><td>file_uploads</td><td>$uploads</td><td></td></tr>
                            <tr class="$maxfile_tr"><td>upload_max_filesize</td><td>$maxfile</td><td>$maxfile_msg</td></tr>
                            <tr class="$postmax_tr"><td>post_max_size</td><td>$postmax</td><td>$postmax_msg</td></tr>
                        </tbody>
                    </table>
                </div>
                
            </div>
        </body>
    </html> 
EOB;

    exit;
}   

}